param($url,$timerjobName)

$snapinAdded = $false

try {
	if ( (Get-PSSnapin -Name Microsoft.Sharepoint.Powershell -ErrorAction SilentlyContinue) -eq $null ) {
		$global:snapinAdded = $true
		Write-Host "Adding Sharepoint module to PowerShell" -NoNewline
		Add-PSSnapin Microsoft.Sharepoint.Powershell -ErrorAction Stop
		Write-Host " - Done."
	}

	Write-Host "Adding Microsoft.Sharepoint assembly" -NoNewline
	Add-Type -AssemblyName "Microsoft.SharePoint, Version=14.0.0.0, Culture=neutral, PublicKeyToken=71e9bce111e9429c"
	Write-Host " - Done."
	
	Write-Host ""
	Write-Host "Starting `"$timerJobName`" " -NoNewline
	
	$webApp = $null
	if ($url -ne $null -and $url -ne "") {
		Write-Host "for $url " -NoNewLine
		$webApp = Get-SPWebApplication $url
	}
	
	$job = Get-SPTimerJob | where{$_.Name -match $timerjobName} | where{($webApp -eq $null) -or ($webApp -ne $null -and $_.Parent -eq $webApp)}
    if ($job -eq $null)  {
        Write-Host '- Timer job was not found.' -ForegroundColor Red
    }
	else {
		$job | Start-SPTimerJob
		Write-Host "- Done." -ForegroundColor Green
	}
}
catch {
	Write-Host ""
    Write-Host "Error starting timer job $timerJobName: " $error[0] -ForegroundColor Red
	throw
	Exit 1
}
finally {
	if ($global:snapinAdded -eq $true) {
		Write-Host ""
		Write-Host "Removing Sharepoint module from PowerShell" -NoNewline
		Remove-PSSnapin Microsoft.Sharepoint.Powershell -ErrorAction SilentlyContinue
		Write-Host " - Done."
		Write-Host ""
	}
}